@@ -74,7 +74,7 @@
 	clippy::cast_precision_loss,
 	clippy::cast_sign_loss,
 	clippy::cast_possible_wrap,
-	clippy::clippy::cast_possible_truncation,
+	clippy::cast_possible_truncation,
 	clippy::module_name_repetitions,
 	clippy::must_use_candidate,
 	clippy::doc_markdown,
